@@ -5,6 +5,7 @@ from pyramid.authorization import ACLAuthorizationPolicy
 
 from .hooks import get_authenticated_user, get_is_authenticated
 from .hooks import get_roles, get_user_json
+from .hooks import get_is_post_login, get_is_post_signup
 from .tree import AuthRoot
 
 def includeme(config):
@@ -16,7 +17,7 @@ def includeme(config):
           >>> mock_config = Mock()
           >>> mock_config.registry.settings = {}
       
-      Adds ``is_authenticated``, ``user`` and ``user_json`` properties to the request::
+      Adds properties to the request::
       
           >>> includeme(mock_config)
           >>> args = (get_is_authenticated, 'is_authenticated')
@@ -25,6 +26,10 @@ def includeme(config):
           >>> mock_config.set_request_property.assert_any_call(*args, reify=True)
           >>> args = (get_user_json, 'user_json')
           >>> mock_config.set_request_property.assert_any_call(*args, reify=True)
+          >>> args = (get_is_post_login, 'is_post_login')
+          >>> mock_config.set_request_property.assert_any_call(*args, reify=True)
+          >>> args = (get_is_post_signup, 'is_post_signup')
+          >>> mock_config.set_request_property.assert_any_call(*args, reify=True)
       
       Exposes the authentication views::
       
@@ -68,6 +73,10 @@ def includeme(config):
     config.set_request_property(get_authenticated_user, 'user', reify=True)
     config.set_request_property(get_user_json, 'user_json', reify=True)
     
+    # Add ``is_post_login`` and ``is_post_signup`` request properties.
+    config.set_request_property(get_is_post_login, 'is_post_login', reify=True)
+    config.set_request_property(get_is_post_signup, 'is_post_signup', reify=True)
+    
     # Expose the authentication views.
     prefix = settings.get('simpleauth.url_prefix', 'auth')
     path = '{0}/*traverse'.format(prefix)
